@@ -98,7 +98,7 @@ class Exceptions:
 
 class NetworkManagerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html)
     """
 
@@ -109,7 +109,9 @@ class NetworkManagerClient:
         self, *, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
     ) -> AssociateCustomerGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        Associates a customer gateway with a device and optionally, with a link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_customer_gateway)
         """
 
@@ -117,7 +119,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> AssociateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        Associates a link to a device.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_link)
         """
 
@@ -130,13 +134,18 @@ class NetworkManagerClient:
         LinkId: str = None
     ) -> AssociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        Associates a transit gateway Connect peer with a device, and optionally, with a
+        link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_transit_gateway_connect_peer)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#can_paginate)
         """
 
@@ -152,7 +161,9 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        Creates a connection between two devices.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_connection)
         """
 
@@ -171,7 +182,9 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        Creates a new device in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_device)
         """
 
@@ -179,7 +192,9 @@ class NetworkManagerClient:
         self, *, Description: str = None, Tags: List["TagTypeDef"] = None
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        Creates a new, empty global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_global_network)
         """
 
@@ -195,7 +210,9 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        Creates a new link for a specified site.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_link)
         """
 
@@ -208,7 +225,9 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        Creates a new site in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_site)
         """
 
@@ -216,31 +235,41 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, ConnectionId: str
     ) -> DeleteConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        Deletes the specified connection in your global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_connection)
         """
 
     def delete_device(self, *, GlobalNetworkId: str, DeviceId: str) -> DeleteDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        Deletes an existing device.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_device)
         """
 
     def delete_global_network(self, *, GlobalNetworkId: str) -> DeleteGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        Deletes an existing global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_global_network)
         """
 
     def delete_link(self, *, GlobalNetworkId: str, LinkId: str) -> DeleteLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        Deletes an existing link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_link)
         """
 
     def delete_site(self, *, GlobalNetworkId: str, SiteId: str) -> DeleteSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        Deletes an existing site.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_site)
         """
 
@@ -248,7 +277,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> DeregisterTransitGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        Deregisters a transit gateway from your global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#deregister_transit_gateway)
         """
 
@@ -256,7 +287,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkIds: List[str] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        Describes one or more global networks.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#describe_global_networks)
         """
 
@@ -264,7 +297,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, CustomerGatewayArn: str
     ) -> DisassociateCustomerGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        Disassociates a customer gateway from a device and a link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_customer_gateway)
         """
 
@@ -272,7 +307,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> DisassociateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        Disassociates an existing device from a link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_link)
         """
 
@@ -280,7 +317,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, TransitGatewayConnectPeerArn: str
     ) -> DisassociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        Disassociates a transit gateway Connect peer from a device and link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_transit_gateway_connect_peer)
         """
 
@@ -292,7 +331,9 @@ class NetworkManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#generate_presigned_url)
         """
 
@@ -306,7 +347,9 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        Gets information about one or more of your connections in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_connections)
         """
 
@@ -319,7 +362,10 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        Gets the association information for customer gateways that are associated with
+        devices and links in your global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_customer_gateway_associations)
         """
 
@@ -333,7 +379,9 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetDevicesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        Gets information about one or more of your devices in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_devices)
         """
 
@@ -347,7 +395,9 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetLinkAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        Gets the link associations for a device or a link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_link_associations)
         """
 
@@ -363,7 +413,9 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetLinksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        Gets information about one or more links in a specified global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_links)
         """
 
@@ -376,7 +428,9 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetSitesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        Gets information about one or more of your sites in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_sites)
         """
 
@@ -389,7 +443,10 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetTransitGatewayConnectPeerAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        Gets information about one or more of your transit gateway Connect peer
+        associations in a global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_connect_peer_associations)
         """
 
@@ -402,13 +459,18 @@ class NetworkManagerClient:
         NextToken: str = None
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        Gets information about the transit gateway registrations in a specified global
+        network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_registrations)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        Lists the tags for a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#list_tags_for_resource)
         """
 
@@ -416,19 +478,25 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> RegisterTransitGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        Registers a transit gateway in your global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#register_transit_gateway)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        Tags a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        Removes tags from a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#untag_resource)
         """
 
@@ -442,7 +510,9 @@ class NetworkManagerClient:
         Description: str = None
     ) -> UpdateConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        Updates the information for an existing connection.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_connection)
         """
 
@@ -461,7 +531,9 @@ class NetworkManagerClient:
         SiteId: str = None
     ) -> UpdateDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        Updates the details for an existing device.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_device)
         """
 
@@ -469,7 +541,9 @@ class NetworkManagerClient:
         self, *, GlobalNetworkId: str, Description: str = None
     ) -> UpdateGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        Updates an existing global network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_global_network)
         """
 
@@ -484,7 +558,9 @@ class NetworkManagerClient:
         Provider: str = None
     ) -> UpdateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        Updates the details for an existing link.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_link)
         """
 
@@ -497,7 +573,9 @@ class NetworkManagerClient:
         Location: "LocationTypeDef" = None
     ) -> UpdateSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        Updates the information for an existing site.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_site)
         """
 
@@ -506,13 +584,15 @@ class NetworkManagerClient:
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
     @overload
@@ -520,13 +600,15 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
     @overload
@@ -534,19 +616,22 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
     @overload
@@ -554,7 +639,8 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
     @overload
@@ -562,5 +648,6 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
